@@ -1208,25 +1208,37 @@ gdl_dock_item_dock_request (GdlDockObject  *object,
         request->rect.width = alloc.width;
         request->rect.height = alloc.height;
 
+        GdlDockItemBehavior behavior = GDL_DOCK_ITEM(object)->behavior;
+
         /* Calculate docking indicator rectangle size for new locations. Only
            do this when we're not over the item's current location. */
         if (request->applicant != object) {
             switch (request->position) {
                 case GDL_DOCK_TOP:
+                    if (behavior & GDL_DOCK_ITEM_BEH_CANT_DOCK_TOP)
+                        return FALSE;
                     request->rect.height *= SPLIT_RATIO;
                     break;
                 case GDL_DOCK_BOTTOM:
+                    if (behavior & GDL_DOCK_ITEM_BEH_CANT_DOCK_BOTTOM)
+                        return FALSE;
                     request->rect.y += request->rect.height * (1 - SPLIT_RATIO);
                     request->rect.height *= SPLIT_RATIO;
                     break;
                 case GDL_DOCK_LEFT:
+                    if (behavior & GDL_DOCK_ITEM_BEH_CANT_DOCK_LEFT)
+                        return FALSE;
                     request->rect.width *= SPLIT_RATIO;
                     break;
                 case GDL_DOCK_RIGHT:
+                    if (behavior & GDL_DOCK_ITEM_BEH_CANT_DOCK_RIGHT)
+                        return FALSE;
                     request->rect.x += request->rect.width * (1 - SPLIT_RATIO);
                     request->rect.width *= SPLIT_RATIO;
                     break;
                 case GDL_DOCK_CENTER:
+                    if (behavior & GDL_DOCK_ITEM_BEH_CANT_DOCK_CENTER)
+                        return FALSE;
                     request->rect.x = request->rect.width * SPLIT_RATIO/2;
                     request->rect.y = request->rect.height * SPLIT_RATIO/2;
                     request->rect.width = (request->rect.width *
@@ -1735,6 +1747,41 @@ gdl_dock_item_new_with_stock (const gchar         *name,
     return GTK_WIDGET (item);
 }
 
+/**
+ * gdl_dock_item_new_with_pixbuf_icon:
+ * @name: Unique name for identifying the dock object.
+ * @long_name: Human readable name for the dock object.
+ * @pixbuf_icon: Pixbuf icon for the dock object.
+ * @behavior: General behavior for the dock item (i.e. whether it can
+ *            float, if it's locked, etc.), as specified by
+ *            #GdlDockItemBehavior flags.
+ * 
+ * Creates a new dock item grip widget with a given pixbuf icon.
+ * Returns: The newly created dock item grip widget.
+ *
+ * Since: 3.3.2
+ **/
+GtkWidget *
+gdl_dock_item_new_with_pixbuf_icon (const gchar         *name,
+                                    const gchar         *long_name,
+                                    const GdkPixbuf     *pixbuf_icon,
+                                    GdlDockItemBehavior  behavior)
+{
+    GdlDockItem *item;
+
+    item = GDL_DOCK_ITEM (g_object_new (GDL_TYPE_DOCK_ITEM, 
+                                        "name", name, 
+                                        "long-name", long_name,
+                                        "pixbuf-icon", pixbuf_icon,
+                                        "behavior", behavior,
+                                        NULL));
+
+    GDL_DOCK_OBJECT_UNSET_FLAGS (item, GDL_DOCK_AUTOMATIC);
+    gdl_dock_item_set_tablabel (item, gtk_label_new (long_name));
+
+    return GTK_WIDGET (item);
+}
+
 /* convenient function (and to preserve source compat) */
 /**
  * gdl_dock_item_dock_to:
